@@ -1,6 +1,6 @@
 package Continuity;
 
-our $VERSION = '0.995';
+our $VERSION = '0.996';
 
 =head1 NAME
 
@@ -26,24 +26,48 @@ Continuity - Abstract away statelessness of HTTP, for stateful Web applications
 
 =head1 DESCRIPTION
 
-This is BETA software, and feedback/code is welcomed.
-
 Continuity is a library to simplify web applications. Each session is written
 and runs as a persistant application, and is able to request additional input
 at any time without exiting. This is significantly different from the
 traditional CGI model of web applications in which a program is restarted for
 each new request.
 
-The program is passed a $request variable which holds the request (including
+The program is passed a C<< $request >> variable which holds the request (including
 any form data) sent from the browser. In concept, this is a lot like a C<$cgi>
 object from CGI.pm with one very very significant difference. At any point in
 the code you can call $request->next. Your program will then suspend, waiting
 for the next request in the session. Since the program doesn't actually halt,
 all state is preserved, including lexicals -- getting input from the browser is
-then similar to doing C<$line=E<lt>E<gt>> in a command-line application.
+then similar to doing C<< $line = <> >> in a command-line application.
 
 =head1 GETTING STARTED
 
+The first thing to make a note of is that your application is a continuously
+running program, basically a self contained webserver. This is quite unlike a
+CGI.pm based application, which is re-started for each new request from a
+client browser. Once you step away from your CGI.pm experience this is actually
+more natural (IMO), more like writing an interactive desktop or command-line
+program.
+
+Here's a simple example:
+
+  #!/usr/bin/perl
+
+  use strict;
+  use Continuity;
+
+  my $server = new Continuity;
+  $server->loop;
+
+  sub main {
+    my $request = shift;
+    while(1) {
+      $request->print("Hello, world!");
+      $request->next;
+      $request->print("Hello again!");
+    }
+  }
+
 First, check out the small demo applications in the eg/ directory of the
 distribution. Sample code there ranges from simple counters to more complex
 multi-user ajax applications. All of the basic uses and some of the advanced
@@ -63,8 +87,8 @@ listening for incoming requests and starting new sessions (this never exits).
   $server->loop;
 
 Continuity must have a starting point when starting new sessions for your
-application. The default is C<\&::main> (a sub named "main" in the default
-global scope), which is passed the C<$request> handle. See the
+application. The default is C<< \&::main >> (a sub named "main" in the default
+global scope), which is passed the C<< $request >> handle. See the
 L<Continuity::Request> documentation for details on the methods available from
 the C<$request> object beyond this introduction.
 
@@ -276,7 +300,7 @@ sub new {
     mapper => undef,
     adapter => undef,
     debug_level => 1,
-    debug_callback => sub { print "@_\n" },
+    debug_callback => sub { print STDERR "@_\n" },
     reload => 1, # XXX
     callback => (exists &::main ? \&::main : undef),
     staticp => sub { $_[0]->url =~ m/\.(jpg|jpeg|gif|png|css|ico|js)$/ },
@@ -303,7 +327,7 @@ sub new {
       docroot => $self->{docroot},
       server => $self,
       debug_level => $self->debug_level,
-      debug_callback => sub { print "@_\n" },
+      debug_callback => $self->debug_callback,
       no_content_type => $self->{no_content_type},
       $self->{port} ? (LocalPort => $self->{port}) : (),
       $self->{cookie_life} ? (cookie_life => $self->{cookie_life}) : (), 
